# Tutorials

:::{seealso}
For more tutorials featuring scanpy and other [scverse](https://scverse.org) ecosystem tools, check out the curated set of tutorials at [scverse.org/learn](https://scverse.org/learn)
:::

## Basic workflows

```{toctree}
:maxdepth: 2

basics/index
```

## Visualization

```{toctree}
:maxdepth: 2

plotting/index
```

## Trajectory inference

```{seealso}
For more powerful tools for analysing single cell dynamics, check out the Scverse ecosystem packages:

* [CellRank](https://cellrank.readthedocs.io)
* [Dynamo](https://dynamo-release.readthedocs.io/en/latest/)
```

```{toctree}
:maxdepth: 2

trajectories/index
```

## Spatial data


## Experimental

```{toctree}
:maxdepth: 2

experimental/index
```

## Older tutorials

A number of older tutorials can be found at:

* The [`scanpy_usage`](https://github.com/scverse/scanpy_usage) repository

```{seealso}
Scanpy used to have tutorials for its (now deprecated) spatial data functionality.x
For up-to-date tutorials on working with spatial data, see:

* SquidPy {doc}`squidpy:notebooks/tutorials/index`
* [SpatialData tutorials](https://spatialdata.scverse.org/en/latest/tutorials/notebooks/notebooks.html)
* [Scverse ecosystem spatial tutorials](https://scverse.org/learn/)
```
